import {} from "@netlify/functions";
import { NetlifyExtensionClient } from "@netlify/sdk--extension-api-client";
import { z } from "zod";
const SDKContextProviderTokensSchema = z.array(z.object({
    token: z.string().min(1).trim(),
    externalId: z.string().min(1).trim(),
    connectionId: z.string().min(1).trim(),
}));
const parseProviderTokens = (header) => {
    if (!header) {
        return [];
    }
    try {
        return SDKContextProviderTokensSchema.parse(JSON.parse(header));
    }
    catch (e) {
        console.error("Failed to parse provider tokens header", e);
        return [];
    }
};
// TODO(ndhoule): Divorce this from Request? This is sort of purpose-built for tRPC right now but we
// should be able to use it in non-tRPC/normal request handlers
export const createNetlifySDKContext = ({ req, }) => {
    const netlifyToken = req.headers.get("Nf-UIExt-Netlify-Token");
    const slug = req.headers.get("Nf-UIExt-Extension-Slug");
    const client = new NetlifyExtensionClient(netlifyToken ?? "", slug ?? "", // FIXME(ndhoule): This ain't great, we really should bail out slug is not available
    { netlifyApiUrl: process.env["NETLIFY_API_BASE_URL"] });
    const providerTokens = parseProviderTokens(req.headers.get("Nf-UIExt-Provider-Tokens") ?? "");
    return {
        auth: {
            netlifyToken,
            providerToken: req.headers.get("Nf-UIExt-Provider-Token"),
            providerTokens,
        },
        client,
        siteId: req.headers.get("Nf-UIExt-Site-Id"),
        teamId: req.headers.get("Nf-UIExt-Team-Id"),
    };
};
//# sourceMappingURL=sdk_context.js.map